# kaigara

**kaigara** is a library for morphological studies on molluscan shells.

Website: []()

## Installation


## Usage


## License
This project uses the following license: [ISC License](LICENSE).
